### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Interfaces for the Zope 3 based product package

$Id: interfaces.py 51890 2008-10-21 08:05:28Z cray $
"""
__author__  = ""
__license__ = "GPL"
__version__ = "$Revision: 51890 $"
 
from zope.interface import Interface

class IUseInterfaceWave(Interface) :
    """ InterfaceWave will be used on object having the interface """
                            
class IPropagateInterface(Interface) :
    """ Subinterfaces of the interface will be propagate on container items """
    


from zope.schema.vocabulary import SimpleVocabulary
from zope.interface import implements
from zope.schema.interfaces import IVocabularyTokenized
from zope.schema.vocabulary import SimpleTerm

from zope.app.intid.interfaces import IIntIds
import zope.app.zapi

def IntIdsVocabulary(context):
    """IntIds utility vocabulary"""
    utils = zope.app.zapi.getUtilitiesFor(IIntIds, context)
    return SimpleVocabulary.fromValues(dict(utils).keys())



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""The object event channel

$Id: objecteventchannel.py 51890 2008-10-21 08:05:28Z cray $
"""
__author__  = "Andrey Orlov 2006 12 05"
__license__ = "GPL"
__version__ = "$Revision: 51890 $"

from zope.interface import implements
from zope.event import subscribers

def objectEventChannel(event) :
    #notify(event.object,event)
    #notify is misdeclared as one-argument function and we are to use
    #its content to call all dispatcher 
    for dispatch in subscribers :
        dispatch(event.object,event)
        


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Event Handler used to propagate container interface on his new content

$Id: interfacewave.py 51890 2008-10-21 08:05:28Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51890 $"

from interfaces import IPropagateInterface
from zope.app.container.interfaces import IContained
from zope.interface import alsoProvides, providedBy

def InterfaceWave(ob,event) :
    try :
        cont = IContained(ob).__parent__
    except TypeError :
        print "Can't propagate interface on not-IContent object"
    else :
        for interface in providedBy(cont) :
            if interface.extends(IPropagateInterface) :
                alsoProvides(ob, interface)
